# -*- coding: utf-8 -*-
#
# ewatercycle documentation build configuration file, created by
# sphinx-quickstart on Wed Aug 29 15:40:09 2018.
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys

here = os.path.dirname(__file__)
sys.path.insert(0, os.path.abspath(os.path.join(here, '..')))


# -- General configuration ------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ['sphinx.ext.autodoc', 'sphinx.ext.napoleon', 'nbsphinx', 'sphinx.ext.intersphinx']

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = '.rst'

# The master toctree document.
master_doc = 'index'

# General information about the project.
project = u'ewatercycle'
copyright = u'2018, Netherlands eScience Center & Delft University of Technology'
author = u'Stefan Verhoeven'

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.
# The full version, including alpha/beta/rc tags.
# TODO update version
release = '1.0.0'

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = None

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = False


# -- Run apidoc plug-in manually, as readthedocs doesn't support it -------
# See https://github.com/rtfd/readthedocs.org/issues/1139
def run_apidoc(_):
    here = os.path.dirname(__file__)
    out = os.path.abspath(os.path.join(here, 'apidocs'))
    src = os.path.abspath(os.path.join(here, '..', 'ewatercycle'))

    ignore_paths = []

    argv = [
        "-f",
        "-T",
        "-e",
        "-M",
        "--implicit-namespaces",
        "-o", out,
        src
    ] + ignore_paths

    try:
        # Sphinx 1.7+
        from sphinx.ext import apidoc
        apidoc.main(argv)
    except ImportError:
        # Sphinx 1.6 (and earlier)
        from sphinx import apidoc
        argv.insert(0, apidoc.__file__)
        apidoc.main(argv)


def setup(app):
    app.connect('builder-inited', run_apidoc)


# -- Options for HTML output ----------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
#html_theme = 'alabaster'
html_theme = 'sphinx_rtd_theme'
html_logo = 'examples/logo.png'

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#
# html_theme_options = {}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

# Custom sidebar templates, must be a dictionary that maps document names
# to template names.
#
# This is required for the alabaster theme
# refs: http://alabaster.readthedocs.io/en/latest/installation.html#sidebars
html_sidebars = {
    '**': [
        'relations.html',  # needs 'show_related': True theme option to display
        'searchbox.html',
    ]
}


# -- Options for HTMLHelp output ------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = 'ewatercycle_doc'


# -- Options for LaTeX output ---------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    # 'papersize': 'letterpaper',

    # The font size ('10pt', '11pt' or '12pt').
    #
    # 'pointsize': '10pt',

    # Additional stuff for the LaTeX preamble.
    #
    # 'preamble': '',

    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto, manual, or own class]).
latex_documents = [
    (master_doc, 'ewatercycle.tex', u'ewatercycle Documentation',
     u'Stefan Verhoeven', 'manual'),
]


# -- Options for manual page output ---------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    (master_doc, 'ewatercycle', u'ewatercycle Documentation',
     [author], 1)
]


# -- Options for Texinfo output -------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (master_doc, 'ewatercycle', u'ewatercycle Documentation',
     author, 'ewatercycle', 'Python utilities to gather input files for running a hydrology model',
     'Miscellaneous'),
]

autodoc_mock_imports = [
    'basic_modeling_interface',
    'cftime',
    'dask',
    'esmvalcore',
    'fiona',
    'dateutil',
    'shapely',
    'hydrostats',
    'matplotlib',
    'numpy',
    'pandas',
    'pyoos',
    'grpc4bmi',
    'grpc',
    'ruamel.yaml',
    'scipy',
    'xarray',
]

# Prevent alphabetic sorting of (@data)class attributes/methods
autodoc_member_order = 'bysource'

# nbsphinx configuration values cf. https://nbsphinx.readthedocs.io/en/0.8.6/usage.html
nbsphinx_execute = 'never'

# Hacky way to 'remove' the cell count from the prompt.
# Inspired by https://github.com/spatialaudio/nbsphinx/issues/126
nbsphinx_prompt_width = '0'
nbsphinx_input_prompt = '%s         In:'
nbsphinx_output_prompt = '%s       Out:'

# Nice formatting of model-specific input parameters
napoleon_custom_sections = [
    ('hype', 'params_style'),
    ('lisflood', 'params_style'),
    ('marrmot', 'params_style'),
    ('pcrglobwb', 'params_style'),
    ('wflow', 'params_style'),
]

intersphinx_mapping = {
    'cf_units': ('https://scitools.org.uk/cf-units/docs/latest/', None),
    'esmvalcore':
    (f'https://docs.esmvaltool.org/projects/esmvalcore/en/latest/',
     None),
    'esmvaltool': (f'https://docs.esmvaltool.org/en/latest/', None),
    'grpc4bmi': (f'https://grpc4bmi.readthedocs.io/en/latest/', None),
    'iris': ('https://scitools-iris.readthedocs.io/en/latest/', None),
    'lime': ('https://lime-ml.readthedocs.io/en/latest/', None),
    'basic_modeling_interface': ('https://bmi.readthedocs.io/en/latest/', None),
    'matplotlib': ('https://matplotlib.org/', None),
    'numpy': ('https://numpy.org/doc/stable/', None),
    'pandas': ('https://pandas.pydata.org/pandas-docs/dev', None),
    'python': ('https://docs.python.org/3/', None),
    'scipy': ('https://docs.scipy.org/doc/scipy/reference/', None),
    'seaborn': ('https://seaborn.pydata.org/', None),
    'sklearn': ('https://scikit-learn.org/stable', None),
}
